@@ -236,43 +236,6 @@ def shell(commands) -> tuple:
             return False, str(err)
     return True, ""
 
-@click.command(help="Enable wayland")
-def enable_wayland():
-    wayland_success = subprocess.run(
-        "pkexec sed -i 's/^WaylandEnable=false/#WaylandEnable=false/' /etc/gdm/custom.conf", shell=True, check=False)
-    if wayland_success.returncode == 0:
-        return True
-    return False
-
-@click.command(help="Disable wayland")
-def disable_wayland():
-    wayland_success = subprocess.run(
-        "pkexec sed -i 's/^#WaylandEnable=false/WaylandEnable=false/' /etc/gdm/custom.conf", shell=True, check=False)
-    if wayland_success.returncode == 0:
-        return True
-    return False
-
-def get_wayland_state():
-    wayland_enabled = subprocess.run(
-        "grep -q '^WaylandEnable=false' /etc/gdm/custom.conf", shell=True, check=False).returncode == 1
-    if wayland_enabled and not nvidia_present:
-        return True
-    return False
-
-def toggle_wayland():
-    if get_wayland_state():
-        wayland_success = subprocess.run(
-            "pkexec sed -i 's/^#WaylandEnable=false/WaylandEnable=false/' /etc/gdm/custom.conf", shell=True, check=False)
-        if wayland_success.returncode == 0:
-            return True
-        return False
-    else:
-        wayland_success = subprocess.run(
-            "pkexec sed -i 's/^WaylandEnable=false/#WaylandEnable=false/' /etc/gdm/custom.conf", shell=True, check=False)
-        if wayland_success.returncode == 0:
-            return True
-        return False
-
 def get_extensions(chosen_layout):
     # List needed extensions
     extensions = {
@@ -376,10 +339,7 @@ class LayoutBox(Gtk.Box):
         self.btn_layout_first = None
         self.branding_handler_id = None
         self.branding_active = None
-        self.wayland_handler_id = None
-        self.wayland_active = None
         self.pop_id = None
-        self.wayland_active = None
 
         with UserConf() as conf:
             self.layout = conf.read("layout", "manjaro")
@@ -497,26 +457,6 @@ class LayoutBox(Gtk.Box):
         manjaro_label.set_markup("Manjaro branding")
         manjaro_label.props.halign = Gtk.Align.START
 
-        # wayland toggle
-        wayland_switch = Gtk.Switch()
-        wayland_switch.props.valign = Gtk.Align.CENTER
-        wayland_switch.props.halign = Gtk.Align.CENTER
-
-        if get_wayland_state():
-            wayland_switch.set_active(True)
-        else:
-            wayland_switch.set_active(False)
-        if nvidia_present:
-            wayland_switch.set_sensitive(False)
-        wayland_switch.connect("notify::active", self.on_wayland_activated)
-        wayland_label = Gtk.Label()
-        wayland_label.set_markup("Wayland session")
-        wayland_label.props.halign = Gtk.Align.START
-
-        self.wayland_active = get_wayland_state()
-        wayland_switch.set_active(self.wayland_active)
-        self.wayland_handler_id = wayland_switch.connect(
-            "notify::active", self.on_wayland_activated)
         # System tray
         tray_switch = Gtk.Switch()
         tray_switch.props.valign = Gtk.Align.CENTER
@@ -603,12 +543,10 @@ class LayoutBox(Gtk.Box):
         theme_grid.attach(gdm_settings_label, 1, 3, 2, 1)
         theme_grid.attach(tray_switch, 6, 0, 1, 1)
         theme_grid.attach(tray_label, 4, 0, 2, 1)
-        theme_grid.attach(wayland_switch, 6, 1, 1, 1)
-        theme_grid.attach(wayland_label, 4, 1, 2, 1)
-        theme_grid.attach(desk_switch, 6, 2, 1, 1)
-        theme_grid.attach(desk_label, 4, 2, 2, 1)
-        theme_grid.attach(firefox_theme_button, 6, 3, 1, 1)
-        theme_grid.attach(firefox_theme_label, 4, 3, 2, 1)
+        theme_grid.attach(desk_switch, 6, 1, 1, 1)
+        theme_grid.attach(desk_label, 4, 1, 2, 1)
+        theme_grid.attach(firefox_theme_button, 6, 2, 1, 1)
+        theme_grid.attach(firefox_theme_label, 4, 2, 2, 1)
 
 
     def set_preview_colors(self, newcolor: str):
@@ -745,18 +683,6 @@ class LayoutBox(Gtk.Box):
                 "gnome-extensions disable appindicatorsupport@rgcjonas.gmail.com", shell=True, check=False)
         print("System tray was turned", state)
 
-    def on_wayland_activated(self, switch, gparam):
-        # Toggle state
-        toggle_wayland()
-        # Disconnect the switch
-        switch.disconnect(self.wayland_handler_id)
-        if get_wayland_state():
-            print("Wayland is on")
-            switch.set_active(True)
-        else:
-            print("Wayland is off")
-            switch.set_active(False)
-
     # ------------- branding -------------------------------------------
     def on_branding_activated(self, switch, gparam):
         self.change_branding(switch)
@@ -844,5 +770,3 @@ class Command(Gtk.Box):
     cli.add_command(apply_manjaro)
     cli.add_command(apply_gnome)
     cli.add_command(apply_tiling)
-    cli.add_command(enable_wayland)
-    cli.add_command(disable_wayland)
